@@ -21,11 +21,13 @@ app_server <- function( input, output, session ) {
   ### Optimized Arrangement
   mod_Optim_server("Optim_ui_1")
   ################## Augmented Designs ###########################################
-  ### Diagonal Augmented
   ### RCBD Augmented
   mod_RCBD_augmented_server("RCBD_augmented_ui_1")
+  ################## Sparse Allocation ###########################################
+  mod_sparse_allocation_server("sparse_allocation_ui_1")
   ################## Partially Replicated Module #################################
   mod_pREPS_server("pREPS_ui_1")
+  mod_multi_loc_preps_server("multi_loc_preps_ui_1")
   ################## Lattice Designs #############################################
   ### Square Lattice
   mod_Square_Lattice_server("Square_Lattice_ui_1")
